@@ -10,7 +10,7 @@ require Exporter;
 @EXPORT    = qw( confess carp croak );
 @EXPORT_OK = qw( cluck click register_source );
 
-$VERSION   = '1.32';
+$VERSION   = '1.33';
 
 require Carp;
 require Carp::Heavy;
@@ -393,7 +393,7 @@ the following workaround:
 
   require Win32;
 
-  if (Win32::WinNT) {
+  if (Win32::IsWinNT) {
     require Win32::EventLog::Carp;
     import Win32::EventLog::Carp 1.31;
   }
